import icons from './icons/index';
export type IconColor = 'default' | 'subtle' | 'success' | 'error' | 'warning' | 'info' | 'recommendation' | 'inverse' | 'shopping' | 'brandPrimary' | 'light' | 'dark';
type Props = {
    /**
     * Label for screen readers to announce Icon. This populates the `aria-label` attribute. If the label is hidden, use an empty string for the label (`accessibilityLabel=""`) to set `aria-hidden`.
     *
     * See the [Accessibility guidelines](https://gestalt.pinterest.systems/web/icon#Accessibility) for details on proper usage.
     */
    accessibilityLabel: string;
    /**
     * The colors available to apply to Icon.
     *
     * See the [color variant](https://gestalt.pinterest.systems/web/icon#Colors) to learn more.
     */
    color?: IconColor;
    /**
     * SVG icon from the Gestalt icon library to use within Icon.
     *
     * See the [icon library](https://gestalt.pinterest.systems/foundations/iconography/library) to explore available options.
     */
    icon?: keyof typeof icons;
    /**
     * Defines a new icon different from the built-in Gestalt icons.
     *
     * See the [custom icon](https://gestalt.pinterest.systems/web/icon#Custom-icon) variant to learn more.
     */
    dangerouslySetSvgPath?: {
        __path: string;
    };
    /**
     * Properly positions Icon relative to an inline element, such as Text using the inline property.
     */
    inline?: boolean;
    /**
     * Use a number for pixel sizes or a string for percentage based sizes.
     *
     * See the [size](https://gestalt.pinterest.systems/web/icon#Size) variant to learn more.
     */
    size?: number | string;
};
/**
 * [Icons](https://gestalt.pinterest.systems/web/icon) are the symbolic representation of an action or information, providing visual context and improving usability.
 *
 * See the [Iconography and SVG guidelines](https://gestalt.pinterest.systems/foundations/iconography/library) to explore the full icon library.
 *
 * ![Icon light mode](https://raw.githubusercontent.com/pinterest/gestalt/master/playwright/visual-test/Icon-list.spec.mjs-snapshots/Icon-list-chromium-darwin.png)
 * ![Icon dark mode](https://raw.githubusercontent.com/pinterest/gestalt/master/playwright/visual-test/Icon-list-dark.spec.mjs-snapshots/Icon-list-dark-chromium-darwin.png)
 *
 */
declare function Icon({ accessibilityLabel, color, dangerouslySetSvgPath, icon, inline, size, }: Props): import("react/jsx-runtime").JSX.Element;
declare namespace Icon {
    var icons: readonly ("shrink" | "filter" | "color" | "replace" | "search" | "link" | "code" | "menu" | "select" | "table" | "template" | "animate" | "text" | "key" | "security" | "alert" | "timer" | "location" | "move" | "pen" | "cancel" | "pause" | "play" | "3D" | "3D-move" | "360" | "accessibility" | "ad" | "ad-group" | "add" | "add-circle" | "add-layout" | "add-pin" | "add-section" | "ads-stats" | "ads-overview" | "alphabetical" | "align-bottom-center" | "align-bottom-left" | "align-bottom-right" | "align-bottom" | "align-middle" | "align-top-center" | "align-top-left" | "align-top-right" | "align-top" | "android-share" | "angled-pin" | "api" | "apple" | "apps" | "arrow-back" | "arrow-circle-back" | "arrow-circle-down" | "arrow-circle-forward" | "arrow-circle-up" | "arrow-counter-clockwise" | "arrow-double-forward" | "arrow-double-back" | "arrow-down" | "arrow-end" | "arrow-forward" | "arrow-left-curved" | "arrow-start" | "arrow-up" | "arrow-up-left" | "arrow-up-right" | "arrows-vertical" | "bell" | "board" | "briefcase" | "business-hierarchy" | "calendar" | "calendar-check" | "camera" | "camera-flip" | "camera-roll" | "canonical-pin" | "captions" | "captions-outline" | "color-picker" | "check" | "check-circle" | "chevron-up-circle" | "circle-outline" | "clear" | "clock" | "clock-checked" | "cloud-server" | "code-checked" | "cog" | "compass" | "compose" | "collapse" | "color-solid" | "color-split" | "copy-to-clipboard" | "crop" | "data-source" | "dash" | "desktop" | "diagnostics" | "conversion-tag" | "credit-card" | "directional-arrow-left" | "directional-arrow-right" | "download" | "drag-drop" | "duplicate" | "edit" | "ellipsis" | "ellipsis-circle-outline" | "envelope" | "expand" | "eye" | "eye-hide" | "facebook" | "fade" | "face-happy" | "face-neutral" | "face-sad" | "face-smiley" | "face-tryon" | "file-box" | "file-unknown" | "fill-opaque" | "fill-transparent" | "flag" | "flame" | "flash" | "flashlight" | "flipHorizontal" | "flipVertical" | "folder" | "forward" | "gif" | "globe" | "globe-checked" | "gmail" | "graph-bar" | "graph-pie" | "handle" | "hand-pointing" | "heart" | "heart-outline" | "heart-broken" | "heart-health" | "history" | "home" | "idea-pin" | "image-portrait" | "impressum" | "information" | "insights-audience" | "insights-conversion" | "instagram" | "invoice" | "info-circle" | "knoop" | "layout" | "lightbulb" | "lightning-bolt-circle" | "lips" | "lock" | "logo-large" | "logo-small" | "logout" | "manage-access" | "magic-pen" | "margins-large" | "margins-medium" | "margins-small" | "maximize" | "megaphone" | "minimize" | "mobile" | "moon" | "mute" | "move-pin" | "music-off" | "music-on" | "overlay-text" | "overlay-text-outline" | "overview" | "people" | "person" | "person-add" | "phone" | "pin" | "pin-hide" | "pinterest" | "protect" | "refresh" | "question-mark" | "remove" | "reorder-images" | "report" | "rewind" | "rotate" | "save-outline" | "saved" | "scale" | "scissors" | "search-by-image" | "service-dropbox" | "service-etsy" | "service-messenger" | "service-outlook" | "service-yahoo" | "service-youtube" | "share" | "shopping-bag" | "skintone" | "smiley" | "smiley-outline" | "send" | "sound" | "sort-ascending" | "sort-descending" | "sparkle" | "speech" | "speech-ellipsis" | "speech-exclamation-point" | "speech-heart" | "speech-outline" | "spread" | "star-outline" | "star" | "star-half" | "sticker" | "sun" | "switch-account" | "tag" | "terms" | "text-align-left" | "text-align-center" | "text-align-right" | "text-all-caps" | "text-extra-small" | "text-large" | "text-line-height" | "text-medium" | "text-sentence-case" | "text-size" | "text-small" | "text-spacing" | "thumbs-down" | "thumbs-up" | "trash-can" | "target" | "trending" | "twitter" | "upload-feed" | "video-advance-10-seconds" | "video-camera" | "video-rewind-10-seconds" | "view-type-default" | "view-type-dense" | "view-type-list" | "view-type-space" | "visit" | "whats-app" | "wifi-no" | "workflow-status-all" | "workflow-status-canceled" | "workflow-status-halted" | "workflow-status-in-progress" | "workflow-status-ok" | "workflow-status-problem" | "workflow-status-queued" | "workflow-status-unstarted" | "workflow-status-warning" | "x" | "arrow-nested" | "aspect-ratio" | "audio-bars" | "audio-mix" | "audio-playing" | "board-stickerLarge" | "board-stickerSmall" | "border" | "border-shadow" | "clips" | "collage" | "color-palette" | "contrast" | "cutout" | "design" | "draw" | "erase-auto" | "erase" | "flash-slash" | "gauge" | "ghost" | "hand" | "highlights" | "lab-flask" | "lasso-magic" | "magic-wand" | "microphone" | "orientation-landscape" | "orientation-portrait" | "paper-clip" | "paper-lines-plus" | "pen-auto" | "performance-plus" | "person-magnifying-glass" | "record-limit-5" | "record-limit-10" | "record-limit-15" | "record-limit-30" | "record-limit-60" | "record-limit" | "redo" | "saturation" | "shadows" | "shapes" | "shuffles" | "slide" | "soundSlash" | "speed-.3x" | "speed-.5x" | "speed-1x" | "speed-2x" | "speed-3x" | "speed" | "sticker-image" | "swap" | "text-sticker" | "timer-3" | "timer-10" | "undo" | "warmth" | "wave")[];
    var displayName: string;
}
export default Icon;
